@@ -50,9 +50,9 @@ class Post(Article):
 
     def all_images(self, check_published=True):
         cachekey = _cache_key(
-            '{}main-all_images'.format(self.__class__.__name__),
+            '{0}main-all_images'.format(self.__class__.__name__),
             self.__class__, self.site_domain,
-            u"{}-{}".format(self.channel_long_slug, self.slug))
+            u"{0}-{1}".format(self.channel_long_slug, self.slug))
         getcache = cache.get(cachekey)
         if getcache and check_published:
             return getcache
@@ -72,12 +72,12 @@ class Post(Article):
             if check_published:
                 images = images.filter(published=True)
 
-            captions = {
-                ci.image_id: ci.caption for ci in
+            captions = dict([
+                (ci.image_id, ci.caption) for ci in
                 ContainerImage.objects.filter(
                     container_id=album.pk
                 )
-            }
+            ])
 
             for image in images:
                 caption = captions.get(image.pk)
