@@ -34,6 +34,13 @@ class Channel(MPTTModel, Publishable, Slugged):
     hat = models.CharField(_(u"Hat"),
                            max_length=255, null=True, blank=True)
 
+    main_image = models.ForeignKey(
+        'images.Image',
+        null=True, blank=True,
+        on_delete=models.SET_NULL,
+        verbose_name=_(u'Main Image'),
+    )
+
     show_in_menu = models.BooleanField(_(u"Show in menu?"), default=False)
     include_in_main_rss = models.BooleanField(
         _(u"Show in main RSS?"),
@@ -67,16 +74,17 @@ class Channel(MPTTModel, Publishable, Slugged):
         """ Uniform resource identifier
         http://en.wikipedia.org/wiki/Uniform_resource_identifier
         """
-        return u"/{}/".format(self._set_long_slug())
+        return u"/{0}/".format(self._set_long_slug())
 
     def get_absolute_url(self):
-        return u"{}".format(self.__unicode__())
+        return u"{0}".format(self.__unicode__())
 
     def get_thumb(self):
         return None
 
     def get_http_absolute_url(self):
-        return u"http://{}{}".format(self.site_domain, self.get_absolute_url())
+        return u"http://{0}{1}".format(self.site_domain,
+                                       self.get_absolute_url())
     get_http_absolute_url.short_description = _(u'Get HTTP Absolute URL')
 
     @staticmethod
@@ -110,8 +118,8 @@ class Channel(MPTTModel, Publishable, Slugged):
 
     def _set_long_slug(self):
         if self.parent:
-            return u"{}/{}".format(self.parent.long_slug, self.slug)
-        return u"{}".format(self.slug)
+            return u"{0}/{1}".format(self.parent.long_slug, self.slug)
+        return u"{0}".format(self.slug)
 
     def save(self, *args, **kwargs):
         self.long_slug = self._set_long_slug()
